@@ -1,14 +1,19 @@
 # flake8: noqa
 from tdxapi.enums.aggregate_function import AggregateFunction
+from tdxapi.enums.article_status import ArticleStatus
 from tdxapi.enums.attachment_type import AttachmentType
 from tdxapi.enums.backing_item_type import BackingItemType
 from tdxapi.enums.column_data_type import ColumnDataType
 from tdxapi.enums.component import Component
 from tdxapi.enums.component_function import ComponentFunction
+from tdxapi.enums.conflict_type import ConflictType
 from tdxapi.enums.feed_item_type import FeedItemType
 from tdxapi.enums.license_type import LicenseType
 from tdxapi.enums.sla_start_basis import SlaStartBasis
 from tdxapi.enums.status_class import StatusClass
 from tdxapi.enums.ticket_class import TicketClass
+from tdxapi.enums.ticket_task_type import TicketTaskType
 from tdxapi.enums.time_zone import TimeZone
+from tdxapi.enums.unmet_constraint_search_type import UnmetConstraintSearchType
 from tdxapi.enums.update_type import UpdateType
+from tdxapi.enums.user_type import UserType
