@@ -21,3 +21,8 @@ class UserType(Enum):
     #: as a placeholder for actual users when planning out projects without knowing
     #: exactly who will be acting as the resource in question.
     RESOURCE_PLACEHOLDER = 8
+
+    #: Indicates that the user is classified as a service account. These users will be
+    #: able to authenticate and use the API, but they will not be able to log in to
+    #: TDNext, TDMobile, TDAdmin, or TDClient.
+    SERVICE_ACCOUNT = 9
