@@ -38,17 +38,17 @@ class ConfigurationItemTypeManager(TdxManager, TdxAppMixin):
     @tdx_method("POST", "/api/{appId}/cmdb/types/search")
     def search(
         self,
-        search_text: Optional[str] = None,
         is_active: Optional[bool] = None,
         is_system_defined: Optional[bool] = None,
+        search_text: Optional[str] = None,
     ) -> List[ConfigurationItemType]:
         """Gets a list of configuration item types.
 
-        :param search_text: the search text to filter on. If this is set, this will
-            sort the results by their text relevancy.
-        :param is_active: the active status to filter on.
-        :param is_system_defined: a value indicating whether or not
-            system-defined types will be returned.
+        :param is_active: The active status to filter on.
+        :param is_system_defined: Whether organizationally-defined types will be
+            returned.
+        :param search_text: The search text to filter on. When set, results will be
+            ordered by their text relevancy.
         """
         params = self._format_search_params(ConfigurationItemTypeSearch, locals())
 
