@@ -43,11 +43,11 @@ class ConfigurationRelationshipTypeManager(TdxManager, TdxAppMixin):
     ) -> List[ConfigurationRelationshipType]:
         """Gets a list of configuration relationship types.
 
-        :param description_like: the text to perform a LIKE search on for the
-            relationship type description and inverse description.
-        :param is_active: the active status to filter on.
-        :param is_operational_dependency: the "operational dependency" status to
-            filter on.
+        :param description_like: The text to perform a LIKE search on the relationship
+            type description and inverse description.
+        :param is_active: The active status to filter on.
+        :param is_operational_dependency: The operational dependency status to filter
+            on.
         """
         params = self._format_search_params(
             ConfigurationRelationshipTypeSearch, locals()
