@@ -2,7 +2,6 @@ from typing import Optional
 
 import attr
 
-from tdxapi.enums.component import Component
 from tdxapi.managers.bases import TdxManager, tdx_method
 from tdxapi.models.custom_attribute import CustomAttribute
 from tdxapi.models.custom_attribute_list import CustomAttributeList
@@ -15,18 +14,18 @@ class CustomAttributeManager(TdxManager):
         "/api/attributes/custom"
         "?componentId={componentId}&associatedTypeId={associatedTypeId}&appId={appId}",
     )
-    def get_by_component(
+    def get_by_component_id(
         self,
-        component: Component,
+        component_id: int,
         app_id: Optional[int] = 0,
         associated_type_id: Optional[int] = 0,
     ) -> CustomAttributeList:
         """Gets the custom attributes for the specified component."""
         return CustomAttributeList(
             self.dispatcher.send(
-                self.get_by_component.method,
-                self.get_by_component.url.format(
-                    componentId=component.value,
+                self.get_by_component_id.method,
+                self.get_by_component_id.url.format(
+                    componentId=component_id,
                     associatedTypeId=associated_type_id,
                     appId=app_id,
                 ),
