@@ -25,8 +25,9 @@ class TdxCustomAttributeMixin(object):
 
             cam = CustomAttributeManager(self.dispatcher)
 
-            self._attribute_template = cam.get_by_component(
-                self.__class__.__tdx_component__, app_id=getattr(self, "app_id", 0)
+            self._attribute_template = cam.get_by_component_id(
+                self.__class__.__tdx_component__.value,
+                app_id=getattr(self, "app_id", 0),
             )
 
         return self._attribute_template
