@@ -51,13 +51,13 @@ class ProductModelManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
     ) -> List[ProductModel]:
         """Gets a list of product models.
 
-        :param search_text: the search text to filter on. If this is set, this will sort
-            the results by their text relevancy.
-        :param manufacturer_id: the ID of the manufacturer to filter on.
-        :param product_type_id: the ID of the product type to filter on. This will NOT
+        :param search_text: The search text to filter on. When set, the results will be
+            sorted by their text relevancy.
+        :param manufacturer_id: The ID of the manufacturer to filter on.
+        :param product_type_id: The ID of the product type to filter on. This will NOT
             filter on product subtypes.
-        :param is_active: the active status to filter on.
-        :param attributes: the custom attributes to filter on.
+        :param is_active: The active status to filter on.
+        :param attributes: The custom attributes to filter on.
         """
         params = self._format_search_params(ProductModelSearch, locals())
 
