@@ -42,13 +42,12 @@ class ProductTypeManager(TdxManager, TdxAppMixin):
     ) -> List[ProductType]:
         """Gets a list of product types.
 
-        :param search_text: the search text to filter on. If this is set, this will sort
-            the results by their text relevancy.
-        :param is_active: the active status to filter on.
-        :param is_top_level: a value indicating whether only top-level product types
-            should be included.
-        :param parent_product_type_id: the parent product type ID to filter on. If this
-            is set, only direct children of this type will be included.
+        :param search_text: The search text to filter on. When set, results will be
+            sorted by their text relevancy.
+        :param is_active: The active status to filter on.
+        :param is_top_level: The top-level status to filter on.
+        :param parent_product_type_id: The parent product type ID to filter on. When
+            set, only direct children of this type will be included.
         """
         params = self._format_search_params(ProductTypeSearch, locals())
 
