@@ -48,25 +48,21 @@ class ReportManager(TdxManager):
     @tdx_method("POST", "/api/reports/search")
     def search(
         self,
+        owner_uid: Optional[str] = None,
         search_text: Optional[str] = None,
         app_id: Optional[int] = None,
         app_class: Optional[str] = None,
-        owner_uid: Optional[str] = None,
-        report_source_id: Optional[int] = None,
+        source_id: Optional[int] = None,
     ) -> List[ReportInfo]:
-        """Gets a list of Report Builder reports visible to the user that match the
+        """
+        Gets a list of Report Builder reports visible to the user that match the
         provided search criteria.
 
-        :param search_text: the search text to filter on. This will filter on the name
-            of each report.
-        :param app_id: the ID of the platform application to filter on. If
-            specified, will only include reports belonging to this application.
-        :param app_class: the name of the system application to filter on.
-            If specified, will only include reports belonging to this application.
-        :param owner_uid: the UID of the owner to filter on. If specified, will only
-            return reports owned by this user.
-        :param report_source_id: the ID of the report source to filter on. If
-            specified, will only include reports belonging to this report source.
+        :param owner_uid: The UID of the report owner to filter on.
+        :param search_text: The search text to filter on report names.
+        :param app_id: The ID of the associated platform application to filter on.
+        :param app_class: The system name of the application to filter on.
+        :param source_id: The ID of the associated report source to filter on.
         """
         params = self._format_search_params(ReportSearch, locals())
 
