@@ -2,7 +2,6 @@ from typing import List, Optional
 
 import attr
 
-from tdxapi.enums.license_type import LicenseType
 from tdxapi.managers.bases import TdxManager, tdx_method
 from tdxapi.models.permission import Permission
 from tdxapi.models.security_role import SecurityRole
@@ -32,19 +31,18 @@ class SecurityRoleManager(TdxManager):
     def get_permissions(
         self,
         app_id: Optional[int] = 0,
-        license_type: Optional[LicenseType] = None,
+        license_type_id: Optional[int] = None,
         only_default: Optional[bool] = False,
     ) -> List[Permission]:
         """Gets a list of available permissions for the specified application and
         optionally for the specified license type.
         """
-        if license_type:
-            license_type = license_type.value
-
         return self.dispatcher.send(
             self.get_permissions.method,
             self.get_permissions.url.format(
-                forAppId=app_id, forLicenseType=license_type, onlyDefault=only_default
+                forAppId=app_id,
+                forLicenseType=license_type_id,
+                onlyDefault=only_default,
             ),
             rclass=Permission,
             rlist=True,
@@ -56,15 +54,13 @@ class SecurityRoleManager(TdxManager):
         self,
         name_like: Optional[str] = None,
         app_id: Optional[int] = None,
-        license_type: Optional[LicenseType] = None,
+        license_type_id: Optional[int] = None,
     ) -> List[SecurityRole]:
         """Gets a list of security roles.
 
-        :param name_like: the security role name.
-        :param app_id: the application ID. Providing a non-zero value will search for
-            application-specific security roles, while a value of 0 will search for
-            global security roles.
-        :param license_type: the license type.
+        :param name_like: The text to perform a LIKE search on security role name.
+        :param app_id: The ID of the associated application to filter on.
+        :param license_type_id: The ID of the associated license type to filter on.
         """
         params = self._format_search_params(SecurityRoleSearch, locals())
 
