@@ -4,16 +4,13 @@ from typing import Any, List, Optional, Tuple
 import attr
 
 from tdxapi.enums.component import Component
-from tdxapi.enums.sla_start_basis import SlaStartBasis
-from tdxapi.enums.status_class import StatusClass
-from tdxapi.enums.ticket_class import TicketClass
-from tdxapi.enums.unmet_constraint_search_type import UnmetConstraintSearchType
 from tdxapi.managers import helpers
 from tdxapi.managers.bases import TdxManager, tdx_method
 from tdxapi.managers.mixins import TdxAppMixin, TdxCustomAttributeMixin
 from tdxapi.models.attachment import Attachment
 from tdxapi.models.configuration_item import ConfigurationItem
 from tdxapi.models.item_update import ItemUpdate
+from tdxapi.models.move_ticket_options import MoveTicketOptions
 from tdxapi.models.sla_assignment_options import SlaAssignmentOptions
 from tdxapi.models.sla_removal_options import SlaRemovalOptions
 from tdxapi.models.ticket import Ticket
@@ -45,14 +42,14 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
     @tdx_method("POST", "/api/{appId}/tickets/search")
     def search(
         self,
-        ticket_classifications: Optional[List[TicketClass]] = None,
+        ticket_classification_ids: Optional[List[int]] = None,
         max_results: Optional[int] = None,
         ticket_id: Optional[int] = None,
         parent_ticket_id: Optional[int] = None,
         search_text: Optional[str] = None,
         status_ids: Optional[List[int]] = None,
         past_status_ids: Optional[List[int]] = None,
-        status_classes: Optional[List[StatusClass]] = None,
+        status_class_ids: Optional[List[int]] = None,
         priority_ids: Optional[List[int]] = None,
         urgency_ids: Optional[List[int]] = None,
         impact_ids: Optional[List[int]] = None,
@@ -91,10 +88,10 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         primary_responsibility_group_ids: Optional[List[int]] = None,
         sla_ids: Optional[List[int]] = None,
         sla_violated: Optional[bool] = None,
-        sla_unmet_constraints: Optional[List[UnmetConstraintSearchType]] = None,
+        sla_unmet_constraint_type_ids: Optional[int] = None,
         article_ids: Optional[List[int]] = None,
         is_assigned: Optional[bool] = None,
-        converted_to_task: Optional[bool] = None,
+        is_converted_to_task: Optional[bool] = None,
         reviewer_uid: Optional[str] = None,
         requestor_uids: Optional[List[str]] = None,
         requestor_name_like: Optional[str] = None,
@@ -113,14 +110,15 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
     ) -> List[Ticket]:
         """Gets a list of tickets.
 
-        :param ticket_classifications: The ticket classifications to filter on.
+        :param ticket_classification_ids: The ticket classifications to filter on. Use
+            Ticket to perform no classification filtering.
         :param max_results: The maximum number of results to return.
         :param ticket_id: The ticket ID to filter on.
         :param parent_ticket_id: The parent ticket ID to filter on.
         :param search_text: The search text to filter on.
         :param status_ids: The status IDs to filter on.
         :param past_status_ids: The historical status IDs to filter on.
-        :param status_classes: The status class IDs to filter on.
+        :param status_class_ids: The status class IDs to filter on.
         :param priority_ids: The priority IDs to filter on.
         :param urgency_ids: The urgency IDs to filter on.
         :param impact_ids: The impact IDs to filter on.
@@ -154,18 +152,20 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         :param days_old_to: The maximum age to filter on.
         :param responsibility_uids: The UIDs of the responsible users to filter on.
         :param responsibility_group_ids: The IDs of the responsible groups to filter on.
-        :param responsibility_completed_task: The filter to use for responsibility_uids
-            and responsibility_group_ids with regards to ticket tasks.
+        :param responsibility_completed_task: The filter to use for
+            TeamDynamix.Api.Tickets.TicketSearch.ResponsibilityUids and
+            TeamDynamix.Api.Tickets.TicketSearch.ResponsibilityGroupIDs with regards to
+            ticket tasks.
         :param primary_responsibility_uids: The UIDs of the primarily-responsible users
             to filter on.
         :param primary_responsibility_group_ids: The IDs of the primarily-responsible
             groups to filter on.
         :param sla_ids: The SLA IDs to filter on.
         :param sla_violated: The SLA violation status to filter on.
-        :param sla_unmet_constraints: The unmet SLA deadlines to filter on.
+        :param sla_unmet_constraint_type_ids: The unmet SLA deadlines to filter on.
         :param article_ids: The associated Knowledge Base article IDs to filter on.
         :param is_assigned: The assignment status to filter on.
-        :param converted_to_task: The task conversion status to filter on.
+        :param is_converted_to_task: The task conversion status to filter on.
         :param reviewer_uid: The UID of the reviewing user to filter on.
         :param requestor_uids: The requestor UIDs to filter on.
         :param requestor_name_like: The text to perform a LIKE search on the requestor's
@@ -266,16 +266,14 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         "/api/{appId}/tickets/{id}/classification"
         "?newClassificationId={newClassificationId}",
     )
-    def change_classification(
-        self, classification: TicketClass, ticket_id: int
-    ) -> Ticket:
+    def change_classification(self, classification_id: int, ticket_id: int) -> Ticket:
         """Changes a ticket's classification."""
         return self.dispatcher.send(
             self.change_classification.method,
             self.change_classification.url.format(
                 appId=self.app_id,
                 id=ticket_id,
-                newClassificationId=classification.value,
+                newClassificationId=classification_id,
             ),
             rclass=Ticket,
             rlist=False,
@@ -353,7 +351,7 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         new_sla_id: int,
         ticket_id: int,
         comments: Optional[str] = None,
-        start_basis: Optional[SlaStartBasis] = SlaStartBasis.CURRENT_DATE_TIME,
+        start_basis_id: Optional[int] = None,
         should_cascade: Optional[bool] = None,
         notify: Optional[List[str]] = None,
     ) -> Ticket:
@@ -362,7 +360,7 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
             new_sla_id=new_sla_id,
             ticket_id=ticket_id,
             comments=comments,
-            start_basis=start_basis,
+            start_basis_id=start_basis_id,
             should_cascade=should_cascade,
             notify=notify,
         )
@@ -373,7 +371,7 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         new_sla_id: int,
         ticket_id: int,
         comments: Optional[str] = None,
-        start_basis: Optional[SlaStartBasis] = SlaStartBasis.CURRENT_DATE_TIME,
+        start_basis_id: Optional[int] = None,
         should_cascade: Optional[bool] = None,
         notify: Optional[List[str]] = None,
     ) -> Ticket:
@@ -384,7 +382,7 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
             data=SlaAssignmentOptions(
                 new_sla_id=new_sla_id,
                 comments=comments,
-                start_basis=start_basis,
+                start_basis_id=start_basis_id,
                 should_cascade=should_cascade,
                 notify=helpers.build_notify_list(notify),
             ),
@@ -415,6 +413,35 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
             rpartial=True,
         )
 
+    @tdx_method("POST", "/api/{appId}/tickets/{id}/application")
+    def move_to_application(
+        self,
+        new_app_id: int,
+        new_form_id: int,
+        new_ticket_type_id: int,
+        new_status_id: int,
+        ticket_id: int,
+        comments: Optional[str] = None,
+    ) -> Ticket:
+        """Moves a ticket to a different application."""
+        return self.dispatcher.send(
+            self.move_to_application.method,
+            self.move_to_application.url.format(
+                appId=self.app_id,
+                id=ticket_id,
+            ),
+            data=MoveTicketOptions(
+                new_app_id=new_app_id,
+                new_form_id=new_form_id,
+                new_ticket_type_id=new_ticket_type_id,
+                new_status_id=new_status_id,
+                comments=comments,
+            ),
+            rclass=Ticket,
+            rlist=False,
+            rpartial=True,
+        )
+
     def new(self, **kwargs) -> Ticket:
         """Generate new Ticket object."""
         return self._new(Ticket, **kwargs)
