@@ -30,7 +30,7 @@ class VendorManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         return vendor
 
     @tdx_method("GET", "/api/{appId}/assets/vendors")
-    def all(self) -> List[Vendor]:
+    def all(self) -> List[Vendor]:  # noqa: A003
         """Gets a list of all active vendors."""
         return self.dispatcher.send(
             self.all.method,
@@ -53,17 +53,17 @@ class VendorManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
     ) -> List[Vendor]:
         """Gets a list of vendors.
 
-        :param name_like: the text to perform a LIKE search on for the vendor name.
-        :param search_text: the search text to filter on. If this is set, this will
-            sort the results by their text relevancy.
-        :param only_manufacturers: a value indicating whether or not only vendors who
-            have been classified as product manufacturers should be returned.
-        :param only_suppliers: a value indicating whether or not only vendors who have
-            been classified as asset suppliers should be returned.
-        :param only_contract_providers: a value indicating whether or not only vendors
-            who have been classified as contract providers should be returned.
-        :param is_active: the active status to filter on.
-        :param attributes: the custom attributes to filter on.
+        :param name_like: The text to perform a LIKE search on the vendor name.
+        :param search_text: The search text to filter on. When set, this will sort the
+            results by their text relevancy.
+        :param only_manufacturers: Whether only vendors classified as product
+            manufacturers should be returned.
+        :param only_suppliers: Whether only vendors classified as asset suppliers should
+            be returned.
+        :param only_contract_providers: Whether only vendors classified as contract
+            providers should be returned.
+        :param is_active: The active status to filter on.
+        :param attributes: The custom attributes to filter on.
         """
         params = self._format_search_params(VendorSearch, locals())
 
