@@ -7,11 +7,11 @@ from tdxapi.models.bases import TdxModel
 class ChartSetting(TdxModel):
     __tdx_type__ = "TeamDynamix.Api.Reporting.ChartSetting"
 
-    #: The axis represented by this setting.
+    #: The axis represented by the setting.
     axis = attr.ib(default=None, metadata={"tdx_name": "Axis"})
 
     #: The label describing the column used for the setting.
-    column_label = attr.ib(default=None, metadata={"tdx_name": "ColumnLabel"})
+    label = attr.ib(default=None, metadata={"tdx_name": "ColumnLabel"})
 
     #: The name of the column used for the setting.
-    column_name = attr.ib(default=None, metadata={"tdx_name": "ColumnName"})
+    name = attr.ib(default=None, metadata={"tdx_name": "ColumnName"})
