@@ -76,6 +76,9 @@ class CustomAttributeList(list):
         attr_list = cls(CustomAttribute.from_data(data))
 
         for a in attr_list:
+            if a.value is None:
+                continue
+
             if a.field_type in ["dropdown", "vradio", "hradio", "color"]:
                 a.value = int(a.value)
             elif a.field_type in ["multiselect", "checklist"]:
