@@ -3,8 +3,6 @@ import re
 
 import attr
 
-from tdxapi.enums.feed_item_type import FeedItemType
-from tdxapi.enums.update_type import UpdateType
 from tdxapi.models.bases import TdxModel
 from tdxapi.models.converters import to_datetime, to_uid
 from tdxapi.models.item_update_like import ItemUpdateLike
@@ -16,71 +14,65 @@ from tdxapi.models.participant import Participant
 class ItemUpdate(TdxModel):
     __tdx_type__ = "TeamDynamix.Api.Feed.ItemUpdate"
 
-    #: The id of the feed entry.
+    #: The ID of the feed entry.
     id = attr.ib(default=None, metadata={"tdx_name": "ID"})
 
-    #: The uid of the creator.
+    #: The UID of the feed entry's creator.
     created_uid = attr.ib(
         default=None, converter=to_uid, metadata={"tdx_name": "CreatedUid"}
     )
 
-    #: The integer based id of the creator.
+    #: The integer-based ID of the feed entry's creator.
     created_ref_id = attr.ib(default=None, metadata={"tdx_name": "CreatedRefID"})
 
-    #: The full name of the creator.
+    #: The full name of the feed entry's creator.
     created_full_name = attr.ib(default=None, metadata={"tdx_name": "CreatedFullName"})
 
-    #: The first name of the creator.
+    #: The first name of the feed entry's creator.
     created_first_name = attr.ib(
         default=None, metadata={"tdx_name": "CreatedFirstName"}
     )
 
-    #: The last name of the creator.
+    #: The last name of the feed entry's creator.
     created_last_name = attr.ib(default=None, metadata={"tdx_name": "CreatedLastName"})
 
-    #: The profile image file name of the creator.
+    #: The profile image file path of the feed entry's creator.
     created_profile_image_file_name = attr.ib(
         default=None, metadata={"tdx_name": "CreatedByPicPath"}
     )
 
-    #: The creation date of the feed entry.
+    #: The created date of the feed entry.
     created_date = attr.ib(
         default=None, converter=to_datetime, metadata={"tdx_name": "CreatedDate"}
     )
 
-    #: The date the feed entry was last updated. Replying to this feed entry will
-    #: update this date.
+    #: The last-modified date of the feed entry.
     modified_date = attr.ib(
         default=None, converter=to_datetime, metadata={"tdx_name": "LastUpdatedDate"}
     )
 
-    #: The id of the associated project.
+    #: The ID of the project/workspace/request associated with the feed entry.
     project_id = attr.ib(default=None, metadata={"tdx_name": "ProjectID"})
 
-    #: The name of the associated project.
+    #: The name of the project/workspace/request associated with the feed entry.
     project_name = attr.ib(default=None, metadata={"tdx_name": "ProjectName"})
 
-    #: The id of the associated plan or ticket.
+    #: The ID of the parent item associated with the feed entry.
     plan_id = attr.ib(default=None, metadata={"tdx_name": "PlanID"})
 
-    #: The name of the associated plan or ticket.
+    #: The name of the parent item associated with the feed entry.
     plan_name = attr.ib(default=None, metadata={"tdx_name": "PlanName"})
 
-    #: The item type.
-    item_type = attr.ib(
-        default=FeedItemType.NONE,
-        converter=FeedItemType,
-        metadata={"tdx_name": "ItemType"},
-    )
+    #: The type of the item associated with the feed entry.
+    item_type_id = attr.ib(default=None, metadata={"tdx_name": "ItemType"})
 
-    #: The item id.
+    #: The integer ID of the item associated with the feed entry.
     item_id = attr.ib(default=None, metadata={"tdx_name": "ItemID"})
 
-    #: The item title.
+    #: The title of the item associated with the feed entry.
     item_title = attr.ib(default=None, metadata={"tdx_name": "ItemTitle"})
 
-    #: The reference id. This value is used when the associated item is normally
-    #: referred to by a guid.
+    #: The GUID of the item associated with the feed entry.
     ref_id = attr.ib(
         default=None, converter=to_uid, metadata={"tdx_name": "ReferenceID"}
     )
@@ -88,57 +80,57 @@ class ItemUpdate(TdxModel):
     #: The body of the feed entry.
     body = attr.ib(default=None, metadata={"tdx_name": "Body"})
 
-    #: The type of the feed entry.
-    type = attr.ib(default=0, converter=UpdateType, metadata={"tdx_name": "UpdateType"})
+    #: The update type of the feed entry.
+    type_id = attr.ib(default=None, metadata={"tdx_name": "UpdateType"})
 
-    #: The list of notified people.
+    #: The list of notified users associated with the feed entry.
     notified_list = attr.ib(default=None, metadata={"tdx_name": "NotifiedList"})
 
-    #: A value indicating whether this feed entry is private.
+    #: The private status of the feed entry.
     is_private = attr.ib(default=None, metadata={"tdx_name": "IsPrivate"})
 
-    #: A value indicating whether this feed entry is a parent for other feed entries.
+    #: Indicates if the feed entry is a parent of other feed entries.
     is_parent = attr.ib(default=None, metadata={"tdx_name": "IsParent"})
 
-    #: The replies to this feed entry.
+    #: The replies to the feed entry.
     replies = attr.ib(
         default=attr.Factory(list),
         converter=ItemUpdateReply.from_data,
         metadata={"tdx_name": "Replies"},
     )
 
-    #: The number of replies to this feed entry.
+    #: The number of replies to the feed entry.
     replies_count = attr.ib(default=None, metadata={"tdx_name": "RepliesCount"})
 
-    #: The likes for this feed entry.
+    #: The likes associated with the feed entry.
     likes = attr.ib(
         default=attr.Factory(list),
         converter=ItemUpdateLike.from_data,
         metadata={"tdx_name": "Likes"},
     )
 
-    #: A value inidcating whether this feed entry is liked by the user.
+    #: Indicates whether the user retrieving the feed entry has liked it.
     ilike = attr.ib(default=None, metadata={"tdx_name": "ILike"})
 
-    #: The number of likes for this feed entry.
+    #: The number of people who have liked the feed entry.
     likes_count = attr.ib(default=None, metadata={"tdx_name": "LikesCount"})
 
-    #: The participants. This list consists of the person who is responsible for the
-    #: original feed entry as well as any other individuals who have replied to it.
+    #: The participants associated with the feed entry.
     participants = attr.ib(
         default=attr.Factory(list),
         converter=Participant.from_data,
         metadata={"tdx_name": "Participants"},
     )
 
-    #: The breadcrumbs html. This is not loaded from the database; it is used purely
-    #: for the purpose of sending html to the client for rendering breadcrumbs, and
-    #: should be popualted by the calling application.
+    #: The breadcrumb HTML associated with the feed entry.
     breadcrumbs_html = attr.ib(default=None, metadata={"tdx_name": "BreadcrumbsHtml"})
 
-    #: A value indicating whether this instance has an attachment.
+    #: Not used.
     has_attachment = attr.ib(default=None, metadata={"tdx_name": "HasAttachment"})
 
+    #: The URI to retrieve the full details of the feed entry via the web API.
+    uri = attr.ib(default=None, metadata={"tdx_name": "Uri"})
+
     @property
     def body_text(self):
         # Remove HTML tags
