@@ -1,6 +1,5 @@
 import attr
 
-from tdxapi.enums.sla_start_basis import SlaStartBasis
 from tdxapi.models.bases import TdxModel
 
 
@@ -14,8 +13,9 @@ class SlaAssignmentOptions(TdxModel):
     #: The SLA deadline start basis. The default for this property will be the
     #: SlaStartBasis.CurrentDateTime option. Review the documentation for this property
     #: for all SLA start basis options.
-    start_basis = attr.ib(
-        default=None, converter=SlaStartBasis, metadata={"tdx_name": "StartBasis"}
+    start_basis_id = attr.ib(
+        default=None,
+        metadata={"tdx_name": "StartBasis"},
     )
 
     #: Whether or not to cascade the SLA assignment to child tickets.
