@@ -1,8 +1,5 @@
 import attr
 
-from tdxapi.enums.article_status import ArticleStatus
-from tdxapi.enums.status_class import StatusClass
-from tdxapi.enums.ticket_class import TicketClass
 from tdxapi.models.attachment import Attachment
 from tdxapi.models.bases import TdxModel
 from tdxapi.models.converters import to_datetime, to_uid
@@ -25,10 +22,8 @@ class Ticket(TdxModel):
     parent_title = attr.ib(default=None, metadata={"tdx_name": "ParentTitle"})
 
     #: The classification of the parent associated with the ticket.
-    parent_classification = attr.ib(
-        default=TicketClass.TICKET,
-        converter=TicketClass,
-        metadata={"tdx_name": "ParentClass"},
+    parent_classification_id = attr.ib(
+        default=None, metadata={"tdx_name": "ParentClass"}
     )
 
     #: The ID of the ticket type associated with the ticket.
@@ -46,11 +41,7 @@ class Ticket(TdxModel):
     )
 
     #: The classification associated with the ticket.
-    classification = attr.ib(
-        default=TicketClass.TICKET,
-        converter=TicketClass,
-        metadata={"tdx_name": "Classification"},
-    )
+    classification_id = attr.ib(default=None, metadata={"tdx_name": "Classification"})
 
     #: The application-defined name of the classification associated with the ticket.
     classification_name = attr.ib(
@@ -91,11 +82,7 @@ class Ticket(TdxModel):
     status_name = attr.ib(default=None, metadata={"tdx_name": "StatusName"})
 
     #: The class of the ticket status associated with the ticket.
-    status_class = attr.ib(
-        default=StatusClass.NEW,
-        converter=StatusClass,
-        metadata={"tdx_name": "StatusClass"},
-    )
+    status_class_id = attr.ib(default=None, metadata={"tdx_name": "StatusClass"})
 
     #: The ID of the impact associated with the ticket.
     impact_id = attr.ib(default=None, metadata={"tdx_name": "ImpactID"})
@@ -130,13 +117,13 @@ class Ticket(TdxModel):
 
     #: Whether the Service Level Agreement (SLA) associated with the ticket has its
     #: "Respond By" component violated.
-    is_sla_respond_by_violated = attr.ib(
+    is_respond_by_violated = attr.ib(
         default=None, metadata={"tdx_name": "IsSlaRespondByViolated"}
     )
 
     #: Whether the Service Level Agreement (SLA) associated with the ticket has its
     #: "Resolve By" component violated.
-    is_sla_resolve_by_violated = attr.ib(
+    is_resolve_by_violated = attr.ib(
         default=None, metadata={"tdx_name": "IsSlaResolveByViolated"}
     )
 
@@ -154,7 +141,7 @@ class Ticket(TdxModel):
 
     #: The date the Service Level Agreement (SLA) associated with the ticket was
     #: started.
-    sla_begin_date = attr.ib(
+    sla_start_date = attr.ib(
         default=None, converter=to_datetime, metadata={"tdx_name": "SlaBeginDate"}
     )
 
@@ -387,8 +374,8 @@ class Ticket(TdxModel):
         default=None, converter=to_datetime, metadata={"tdx_name": "TaskStartDate"}
     )
 
-    #: The end date of the associated project task when the ticket has been converted to
-    #: a project task.
+    #: The end date of the associated project task when the ticket has been converted
+    #: to a project task.
     task_end_date = attr.ib(
         default=None, converter=to_datetime, metadata={"tdx_name": "TaskEndDate"}
     )
@@ -422,6 +409,16 @@ class Ticket(TdxModel):
     #: The name of the service associated with the ticket.
     service_name = attr.ib(default=None, metadata={"tdx_name": "ServiceName"})
 
+    #: The ID of the service offering associated with the ticket.
+    service_offering_id = attr.ib(
+        default=None, metadata={"tdx_name": "ServiceOfferingID"}
+    )
+
+    #: The name of the service offering associated with the ticket.
+    service_offering_name = attr.ib(
+        default=None, metadata={"tdx_name": "ServiceOfferingName"}
+    )
+
     #: The ID of the category associated with the ticket's service.
     service_category_id = attr.ib(
         default=None, metadata={"tdx_name": "ServiceCategoryID"}
@@ -439,11 +436,7 @@ class Ticket(TdxModel):
     article_subject = attr.ib(default=None, metadata={"tdx_name": "ArticleSubject"})
 
     #: The ID of the Knowledge Base article associated with the ticket.
-    article_status = attr.ib(
-        default=ArticleStatus.NOT_SUBMITTED,
-        converter=ArticleStatus,
-        metadata={"tdx_name": "ArticleStatus"},
-    )
+    article_status_id = attr.ib(default=None, metadata={"tdx_name": "ArticleStatus"})
 
     #: A delimited string of the category hierarchy associated with the ticket's
     #: Knowledge Base article.
