@@ -11,9 +11,8 @@ class TicketSearch(TdxModel):
 
     #: The ticket classifications to filter on. Use Ticket to perform no classification
     #: filtering.
-    ticket_classifications = attr.ib(
-        default=attr.Factory(list),
-        metadata={"tdx_name": "TicketClassification"},
+    ticket_classification_ids = attr.ib(
+        default=attr.Factory(list), metadata={"tdx_name": "TicketClassification"}
     )
 
     #: The maximum number of results to return.
@@ -37,7 +36,7 @@ class TicketSearch(TdxModel):
     )
 
     #: The status class IDs to filter on.
-    status_classes = attr.ib(
+    status_class_ids = attr.ib(
         default=attr.Factory(list), metadata={"tdx_name": "StatusClassIDs"}
     )
 
@@ -198,7 +197,8 @@ class TicketSearch(TdxModel):
         default=attr.Factory(list), metadata={"tdx_name": "ResponsibilityGroupIDs"}
     )
 
-    #: The filter to use for responsible_uids and responsible_group_ids with regards to
+    #: The filter to use for TeamDynamix.Api.Tickets.TicketSearch.ResponsibilityUids
+    #: and TeamDynamix.Api.Tickets.TicketSearch.ResponsibilityGroupIDs with regards to
     #: ticket tasks.
     responsibility_completed_task = attr.ib(
         default=None, metadata={"tdx_name": "CompletedTaskResponsibilityFilter"}
@@ -224,9 +224,8 @@ class TicketSearch(TdxModel):
     sla_violated = attr.ib(default=None, metadata={"tdx_name": "SlaViolationStatus"})
 
     #: The unmet SLA deadlines to filter on.
-    sla_unmet_constraints = attr.ib(
-        default=None,
-        metadata={"tdx_name": "SlaUnmetConstraints"},
+    sla_unmet_constraint_type_ids = attr.ib(
+        default=None, metadata={"tdx_name": "SlaUnmetConstraints"}
     )
 
     #: The associated Knowledge Base article IDs to filter on.
@@ -238,7 +237,9 @@ class TicketSearch(TdxModel):
     is_assigned = attr.ib(default=None, metadata={"tdx_name": "AssignmentStatus"})
 
     #: The task conversion status to filter on.
-    converted_to_task = attr.ib(default=None, metadata={"tdx_name": "ConvertedToTask"})
+    is_converted_to_task = attr.ib(
+        default=None, metadata={"tdx_name": "ConvertedToTask"}
+    )
 
     #: The UID of the reviewing user to filter on.
     reviewer_uid = attr.ib(
@@ -267,8 +268,9 @@ class TicketSearch(TdxModel):
         default=None, metadata={"tdx_name": "RequestorPhoneSearch"}
     )
 
-    #: The IDs of the associated configuration items to filter on. To be included in the
-    #: search results, a ticket must be associated with one or more of the listed CIs.
+    #: The IDs of the associated configuration items to filter on. To be included in
+    #: the search results, a ticket must be associated with one or more of the listed
+    #: CIs.
     configuration_item_ids = attr.ib(
         default=attr.Factory(list), metadata={"tdx_name": "ConfigurationItemIDs"}
     )
