@@ -1,6 +1,5 @@
 import attr
 
-from tdxapi.enums.status_class import StatusClass
 from tdxapi.models.bases import TdxModel
 
 
@@ -27,11 +26,7 @@ class TicketStatus(TdxModel):
     order = attr.ib(default=None, metadata={"tdx_name": "Order"})
 
     #: The status class associated with the ticket status.
-    status_class = attr.ib(
-        default=StatusClass.NONE,
-        converter=StatusClass,
-        metadata={"tdx_name": "StatusClass"},
-    )
+    status_class_id = attr.ib(default=None, metadata={"tdx_name": "StatusClass"})
 
     #: The active status of the ticket status.
     is_active = attr.ib(default=None, metadata={"tdx_name": "IsActive"})
