@@ -18,7 +18,7 @@ class TicketStatusSearch(TdxModel):
     is_default = attr.ib(default=None, metadata={"tdx_name": "IsDefault"})
 
     #: The status class to filter on.
-    status_class = attr.ib(default=None, metadata={"tdx_name": "StatusClass"})
+    status_class_id = attr.ib(default=None, metadata={"tdx_name": "StatusClass"})
 
     #: The "Requires Goes Off Hold" status to filter on.
     requires_goes_off_hold = attr.ib(
