@@ -1,7 +1,5 @@
 import attr
 
-from tdxapi.enums.time_zone import TimeZone
-from tdxapi.enums.user_type import UserType
 from tdxapi.models.bases import TdxModel
 from tdxapi.models.converters import to_datetime, to_uid
 from tdxapi.models.custom_attribute_list import CustomAttributeList
@@ -224,8 +222,8 @@ class User(TdxModel):
         metadata={"tdx_name": "ReportTimeAfterDate"},
     )
 
-    #: The date after which the user is no longer available for scheduling and no longer
-    #: required to log time.
+    #: The date after which the user is no longer available for scheduling and no
+    #: longer required to log time.
     report_time_end_date = attr.ib(
         default=None, converter=to_datetime, metadata={"tdx_name": "EndDate"}
     )
@@ -251,16 +249,14 @@ class User(TdxModel):
         default=None, metadata={"tdx_name": "ResourcePoolName"}
     )
 
-    #: The time zone associated with the user.
-    tz = attr.ib(
-        default=TimeZone.DEFAULT, converter=TimeZone, metadata={"tdx_name": "TZID"}
-    )
+    #: The ID of the time zone associated with the user.
+    tz_id = attr.ib(default=None, metadata={"tdx_name": "TZID"})
 
     #: The name of the time zone associated with the user.
-    tzname = attr.ib(default=None, metadata={"tdx_name": "TZName"})
+    tz_name = attr.ib(default=None, metadata={"tdx_name": "TZName"})
 
     #: The type of the user.
-    type_id = attr.ib(default=None, converter=UserType, metadata={"tdx_name": "TypeID"})
+    type_id = attr.ib(default=None, metadata={"tdx_name": "TypeID"})
 
     #: The authentication username of the user, used for authenticating with
     #: non-TeamDynamix authentication types.
